function p=autoplot(pl,nl,nr,sx,sy,hp,vp,ht,wt)
% function p=autoplot(pl,nl,nr,sx,sy,hp,vp,ht,wt)
%
% This function is similar to subplot but you can control
% the spacing between the plots.
% It returns a matrix containing the position of all plots
% and opens a figure with a specified size.
% 
% pl - plot command (1 = plot, anything else = do not plot)
% nl - number of columns - controls the height 
% nr - number of rows  - controls the width
% sx - horizontal space between the figures
% sy - vertical space between the figures
% hp - horizontal space around the figures
% vp - vertical space around the figures
% ht - height of the whole figure
% wt - width of the whole figure,
%
% ---------------------------------------------------------------------
% defaults
if     nargin==1,  nr=1;nl=1;sx=.4;sy=.4;hp=.75;vp=1;ht=11;wt=8.5;
elseif nargin==2,  nr=nl;sx=.4;sy=.4;hp=.75;vp=1;ht=11;wt=8.5;
elseif nargin==3,  sx=.4;sy=.4;hp=.75;vp=1;ht=11;wt=8.5;
elseif nargin==4,  sy=sx;hp=.75;vp=1;ht=11;wt=8.5;
elseif nargin==5,  hp=.75;vp=1;ht=11;wt=8.5;
elseif nargin==6,  vp=hp;ht=11;wt=8.5;
elseif nargin==7,  ht=11;wt=8.5;
elseif nargin==8,  wt=(8.5/11)*ht;
end
% ---------------------------------------------------------------------
% landscape x portrait
%
ori='portrait';
if ht<=wt, ori='landscape'; dummy=vp; vp=hp;hp=dummy;clear dummy; end
% ---------------------------------------------------------------------
% define each plot size
%
 h=(ht-2*vp-sy*(nl-1))/nl; w=(wt-2*hp-sx*(nr-1))/nr;
% ---------------------------------------------------------------------
% define paper and screen size
%
set(gcf,'Color',[1 1 1],'InvertHardcopy','on','MenuBar','none','PaperUnits','inches','Units','inches','PaperPosition',[0 0 wt ht],'Position',[.2 .2 wt ht],'paperorientation',ori);
% ---------------------------------------------------------------------
% calculate the position of each plot
%
nfig=nl*nr; % total number of plots 
nf=[1:nfig]';

p1=hp+mod(nf-1,nr)*(w+sx);
p2=vp+flipud(sort(mod(nf-1,nl)))*(h+sy);
p3=w*ones(size(nf));
p4=h*ones(size(nf));

p=[p1 p2 p3 p4];
g=zeros(1,nfig);

if pl==1,
 for i=1:nfig
  g(i)=gca;
  set(g(i),'units','inches','position',p(i,:),'box','on','HandleVisibility','off');
 end
end
set(g,'HandleVisibility','on');









